#!/bin/sh
#
# @(#)12  1.6  src/oss/common/pd_utils/gskit_util/cert_test.sh, oss.common.src, oss510, 031023a 10/23/03 09:06:07
#
# This script will try to extract information from the ldapcacert.b64
# file, and try to run an ldapsearch command, using a 
# Key database (kdb) file created with the certificate.
#
# This script is intended for use by IBM Customer Support.
#  Usage:
#     /opt/pdos/sbin/cert_test.sh  <certificate> [ldap server hostname]
#
# Examples uses for this script:
#   1. Used as a pre-config check of the certificate file to check
#      its lifetime and to make sure yo can talk to the LDAP server 
#      over SSL using this certificate.
#   2. Used to check the lifetime of the certificate to determine if
#      if it time to refresh the certificate. Note: The refresh of the
#      certificate used by AMOS to communicate with LDAP is a manual
#      process. An administrator must check the lifetime of the ldapcert
#      as part of routine maintenance.
#
#
# To enforce data collection in English, set LANG and LC_ALL to C.

LANG=C
LC_ALL=C
#
# Define many things
LDAP1="/usr/bin/ldapsearch"
LDAP2="/usr/ldap/bin/ldapsearch"
LDAP3="/usr/IBMldap/bin/ldapsearch"
AMOSC="/opt/PolicyDirector/lib/ldap.conf"
GSKCMD="/opt/pdos/sbin/gskcapicmd"
FH=$$
CKDB=/tmp/cert_test.${FH}
CPWD="secret"
CLABEL="cert_test"
osseal_pdosshowmsg=/opt/pdos/bin/pdosshowmsg

#
# PrintMessage <default-string>
#
PrintMessage() {
        default=$1
        echo "$default"
        return 0
}



### Ro u t i n e s ###
create_kdb() {
    PrintMessage "Creating Key Database file."
    
    # Create a temporary kdb
    ${GSKCMD} -keydb -create -db ${CKDB}.kdb -stash -pw ${CPWD} -type cms -expire 10
    # Import the specified certificate
    ${GSKCMD} -cert -add -db ${CKDB}.kdb -pw ${CPWD} -label ${CLABEL} -file ${Cert}
    # Show the details of the kdb file.
    PrintMessage "Certificate details:"
    ${GSKCMD} -cert -details -db ${CKDB}.kdb -pw ${CPWD} -label ${CLABEL}
}

remove_kdb() {
    # Remove the temporary kdb files.
    rm -f ${CKDB}.*
}

set_ldap() {
    if [ -x $LDAP1 ]; then
        LDAP=$LDAP1
    elif [ -x $LDAP2 ]; then
        LDAP=$LDAP2
    elif [ -x $LDAP3 ]; then
        LDAP=$LDAP3
    else
        LDAP="NOT_FOUND"
    fi

    if [ -f $AMOSC ]; then
       LDAPHOST=`grep -v "#" $AMOSC | grep host | awk '{print $3}'`
    else
       LDAPHOST="NOT_FOUND"
    fi
}

ping_ldap_ssl() {
    PrintMessage ""
    PrintMessage "Testing connectivity to LDAP Server (SSL)"
    if [ $LDAP = "NOT_FOUND" ]; then
	PrintMessage "Could not find the ldapsearch utility."
        return
    fi
    if [ $LDAPHOST = "NOT_FOUND" ]; then
	PrintMessage "Could not find the LDAP server hostname in the configuration file, /opt/PolicyDirector/etc/ldap.conf." 
        return
    fi
    
    $LDAP -h $LDAPHOST -Z -K ${CKDB}.kdb -b "" -s base -v objectclass=* 1>/dev/null 2>/dev/null
    case $? in
        0) PrintMessage "    OK"
           ;;
        *) PrintMessage "    FAILED"
           ;;
    esac
}


### M A I N ###
#
# Check that we have an argument:
if [ $# -eq 2 ]; then
    set_ldap
    LDAPHOST=$2
elif [ $# -eq 1 ]; then
    set_ldap
else
    PrintMessage "Usage: cert_test.sh <certificate> [ldap server]"
    exit 1;
fi
#
# Check if we are asking for help  -?
if [ "$1" = "-?" ]; then
    PrintMessage "Usage: cert_test.sh <certificate> [ldap server]"
    exit 1;
fi
#
# Check if the file exists.
Cert=$1
if [ ! -f ${Cert} ]; then
    PrintMessage "File not found: ${Cert}"
    exit 1;
fi
#
# Create a key database file based on the certificate, display its
# information and ping the ldap server.
create_kdb
ping_ldap_ssl
remove_kdb

exit 0




