#!/bin/sh
#
# @(#)98       1.12  src/oss/kazn/kdriver/x86_linux_2/kossdump.sh, oss.kazn.src, oss510, 030424a 3/27/03 15:20:57
#
# Copyright (C) Tivoli Systems/IBM. <2000, 2001>
# All Rights Reserved
#
#set -x

####################################################################
####################################################################
#
# Data collection script to extract useful data for diagnosing
# potential AMOS problems.
#
####################################################################
####################################################################

# This script is intended for use by IBM Customer Support. To enforce
# data collection in English, set LANG and LC_ALL to C.
LANG=C
LC_ALL=C

PROGRAM=kossdump.sh
ISLIVE=0
DOFULL=1
PDOSKERN="/opt/pdos/kernel"
PDOSSBIN="/opt/pdos/sbin"
ACTIVE_KERNEL="/proc/kcore"
U=/boot/vmlinux
D=$ACTIVE_KERNEL

print() {
    echo -e $1
}

print_stderr() {
    echo -e $1 > /dev/stderr
}

what()
{
    print "\n\n>>>> $1:"
    /usr/bin/strings $1 | fgrep "src/"
}


##########################################################
##########################################################
# Functions common to all platforms
##########################################################
##########################################################

major_section() {
    stitle=$1
    print ""
    print "OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO"
    print "OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO"
    print "OOO  $stitle"
    print "OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO"
    print "OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO"
    print ""
}


check_exempt()
{
    #
    # Try to become exempt for speed and to minimize change in AMOS state
    #
    /opt/pdos/bin/pdosctl -s pdosd -q
    PDOSD_UP=$?
    if [ $PDOSD_UP = 0 ] ; then
      print "\nRunning pid is $$"
      /opt/pdos/bin/pdosexempt -i $$
      if [ $? -ne 0 ] ; then
	print "1st exempt attempt did not work, try with an su"
        su - osseal -c /opt/pdos/bin/pdosexempt -i $$
      fi
      /opt/pdos/bin/pdoswhoami -l
      /opt/pdos/bin/pdoswhois -l $$
    fi
}


usage() {
  print "usage: $PROGRAM [-d dump_image] [-k kernel] [-b] [-h]"
  print "  -d  platform specific location of system dump image"
  print "      data is collected from the running system by default"
  print "  -k  location of kernel binary image if applicable"
  print "  -b  collect abbreviated kernel data"
  print "  -h  display this usage information"

  print "\n"
  print "$PROGRAM collects AMOS related data for use in problem determination."

  print "Suggested usage examples:"
  print "\nFor general AMOS data collection on a running system:"
  print "  $PROGRAM -b > /tmp/pdosinfo.out"

  print "\nIf applications appear to be blocked or running very slow:"
  print "  $PROGRAM > /tmp/pdosinfo.out"

# This one is not currently applicable to Linux
#
#  print "\nIn the event of a system failure which produces a system dump:"
#  print "  $PROGRAM -d dump_path -k kernel_path > /tmp/pdosinfo.out"

  print "\nCompression of the output file using compress or gzip is"
  print "recommended before sending the information to customer support."

  exit 1
}


#
# Handle optional arguments
#
ProcessArgs () {

  while getopts "hbk:d:" opt; do
    case $opt in
      k)
        U=$OPTARG;;
      d)  
        D=$OPTARG;;
      b)  
        DOFULL=0;;
      h)
	usage;;
      \?)
	usage;;
    esac
  done

  shift $(($OPTIND - 1))

  if [ $# -ne 0 ] ; then
    print "bad arg count $#"
    usage
  fi

#
# Do some general checking
#
  if [ $D = $ACTIVE_KERNEL ] ; then
    ISLIVE=1
  fi

  print "\n\nPoint of collection: `hostname`"
  print "Collection date: `date`"

  EFFID=`/usr/bin/id -u`
  if [ $EFFID != 0 ] ; then
    print "Warning: collection of AMOS information should be done as root"
    print_stderr "Warning: collection of AMOS information should be done as root"
  fi
}


get_kazn_stats()
{
    major_section "AMOS Kernel trace, stats, and error info"
    if [ $ISLIVE = 1 ] ; then
      print "\n\n>>> AMOS Kernel trace data (kazntrace):"
      $PDOSSBIN/kazntrace -l
      print "\n\n\n"
      $PDOSSBIN/kazntrace

      print "\n\n>>> AMOS Kernel statistics data:"
      $PDOSSBIN/kossinfo
      print ""
      $PDOSSBIN/kossinfo -x
      $PDOSSBIN/kossinfo -k
    fi

    print "\n\n>>> msg__kosserrs.log:"
    $PDOSSBIN/kosserrs
    if [ -s /var/pdos/log/msg__kosserrs.log.old ] ; then
      print "\n>>> previous msg__kosserrs.log:"
      $PDOSSBIN/kosserrs -f /var/pdos/log/msg__kosserrs.log.old
    fi
}

#####################################################
#####################################################
#
# Functions that me be somewhat platform specfic
#
#####################################################
#####################################################


get_system_info()
{
    major_section "Local System Information"
    print "\n>>> uname info:"
    uname -a
    print ""
    uptime
    print""

    if [ $ISLIVE = 1 ] ; then
      print ">>> Current running processes (ps -elf):"
      /bin/ps -elf

      for pp in `/bin/ps -ef|grep -E "pdos.*d|KPCF|NCT"|grep -v grep|awk '{print $2}'`
      do
	print "\n\n"
	print "/proc/" $pp
	print "oooooooooooo"
	ls -l /proc/$pp/* 2>/dev/null
	print "\ncmdline: " `cat /proc/$pp/cmdline 2>/dev/null` "\n"
	print "\nenviron: " `cat /proc/$pp/environ 2>/dev/null` "\n"
	print "\nstat"
	cat /proc/$pp/stat 2>/dev/null
	print "\nstatm"
	cat /proc/$pp/statm 2>/dev/null
	print "\nstatus"
	cat /proc/$pp/status 2>/dev/null
      done

      print "\n\n>>> Live vmstat samples"
      /usr/bin/vmstat 2 5
    fi

    print "\n\n>>> kernel:"
    print "\nARCH of kernels installed:"
    rpm -qa --qf "%{NAME}-%{VERSION}-%{RELEASE}: ARCH=%{ARCH}\n" |grep "^k[e_]"

    if [ -s /boot/kernel.h ]; then
	print "\n/boot/kernel.h:"
	cat /boot/kernel.h
    fi
    if [ -s /proc/config.gz ]; then
	print "\n/proc/config.gz:"
	gunzip -c /proc/config.gz
    fi

    print "\n\n>>> Paging, Memory, etc:"
    for aa in swaps meminfo cmdline locks modules slabinfo stat version
    do
	print "\n\n>>> /proc/$aa"
	cat /proc/$aa
    done

    print "\n\n>>> Networking Information:"
    print "netstat -in ..."
    netstat -in
    print "\nnetstat -s ..."
    netstat -s
    print "\nifconfig"
    ifconfig

    print "\n\n>>> File System Information"
    /bin/mount
    print ""
    /bin/df -Pk

    print "\n\n>>> Open File Information"
    /usr/sbin/lsof 2>/dev/null
    /usr/bin/lsof 2>/dev/null
}


get_hw_info()
{
    major_section "H/W Related Information"

    for aa in cpuinfo devices 
    do
	print "\n>>> /proc/$aa:"
	cat /proc/$aa
    done
}


##################################################################
##################################################################
##################################################################
#
# Platform specific functions to extract data from running
# kernels or system dumps.
#
##################################################################
##################################################################


get_kernel_data()
{
    major_section " ... COLLECT AMOS kernel related data ..."

    if [ $ISLIVE = 1 ] ; then
      print "\n>>> Extract data from running kernel image"
    else
      print "\n>>> Extract data from system dump image"
      print "    dump spec: $D"
      print "    kernel spec: $U"
    fi
    print "\n\n"

    ## do some kmem/kcore stuff??

    print "\n\n>>> kaznmod.map:"
    ls -l /opt/pdos/kernel/kaznmod.map
    cat /opt/pdos/kernel/kaznmod.map
    if [ -s /opt/pdos/kernel/kaznmod.map.old ] ; then
      print "\n\n>>> previous kaznmod.map:"
      ls -l /opt/pdos/kernel/kaznmod.map.old
      cat /opt/pdos/kernel/kaznmod.map.old
    fi

    print "\n\n>>> kaznmod.ksyms:"
    ls -l /opt/pdos/kernel/kaznmod.ksyms
    cat /opt/pdos/kernel/kaznmod.ksyms
    if [ -s /opt/pdos/kernel/kaznmod.ksyms.old ] ; then
      print "\n\n>>> previous kaznmod.ksyms:"
      ls -l /opt/pdos/kernel/kaznmod.ksyms.old
      cat /opt/pdos/kernel/kaznmod.ksyms.old
    fi

    print "\n\n>>> kaznmod.modules:"
    ls -l /opt/pdos/kernel/kaznmod.modules
    cat /opt/pdos/kernel/kaznmod.modules
    if [ -s /opt/pdos/kernel/kaznmod.modules.old ] ; then
      print "\n\n>>> previous kaznmod.modules:"
      ls -l /opt/pdos/kernel/kaznmod.modules.old
      cat /opt/pdos/kernel/kaznmod.modules.old
    fi

    print "\n\n>>> Tail of /var/log/messages:"
    tail -300 /var/log/messages

    print "\n\n>>> ksyms:"
    cat /proc/ksyms

    print "\n>>> End of kernel data extraction"
}


####################################################################
# Main Starting point
####################################################################

 #####  #######    #    ######  #######
#     #    #      # #   #     #    #
#          #     #   #  #     #    #
 #####     #    #     # ######     #
      #    #    ####### #   #      #
#     #    #    #     # #    #     #
 #####     #    #     # #     #    #

#     #    #      ###   #     #
##   ##   # #      #    ##    #
# # # #  #   #     #    # #   #
#  #  # #     #    #    #  #  #
#     # #######    #    #   # #
#     # #     #    #    #    ##
#     # #     #   ###   #     #

####################################################################

PROGRAM=`basename $0`
ProcessArgs $@

print_stderr ".... Collecting AMOS information ...."
major_section "AMOS data collection utility"

check_exempt
get_kazn_stats

print_stderr "."

if [ $U != 0 ] ; then
    get_kernel_data
    print_stderr "."
fi

get_system_info

get_hw_info

print_stderr "Done..."
print "\n\n>>> End of Collected Data"

exit 0
