#!/bin/sh
#
# @(#)50  1.8  src/oss/common/pd_utils/server_ping.sh, oss.common.src, oss510, 030717a 7/11/03 10:08:55
#
# This script will try the connection to PD and LDAP servers
# using a configured AMOS
# Define many things
PDADM="/opt/PolicyDirector/bin/pdadmin"
PDSTATUS="/opt/PolicyDirector/.configure/PDRTE"
PDSTATUSLinux="/opt/PolicyDirector/.configure/PDRTE-PD"
PDBAS="/opt/PolicyDirector/sbin/bassslcfg"
PDCONF="/opt/PolicyDirector/etc/pd.conf"
PDMH="master-host"
PDMP="master-port"
PDTEST="user list root 0"
LDAP1="/usr/bin/ldapsearch"
LDAP2="/usr/ldap/bin/ldapsearch"
AMOSC="/opt/PolicyDirector/lib/ldap.conf"
AMOSKDB="/var/pdos/certs/pdosd.kdb"
osseal_pdosshowmsg=/opt/pdos/bin/pdosshowmsg

cat_file=pdosr.cat
failed=35a6109d
ok=35a6109e
ping_server=35a6109f
am_not_found=35a610a0
ldap_host_not_found=35a610a1
ldap_search_not_found=35a610a2
amos_kdb_not_found=35a610a3

#
# PrintMessage <default-string> <message-id> [<arg> [<arg> ...]]
#
PrintMessage() {
        default="$1"
        shift
        if [ -x ${osseal_pdosshowmsg} ]
        then
                if ${osseal_pdosshowmsg} ${cat_file} "$@"
                then
                        return 0
                fi
        fi

        echo "$default"
        return 0
}



### Ro u t i n e s ###
ping_am() {
    PrintMessage "Testing connectivity to Tivoli Access Manager policy server" ${ping_server} "Tivoli Access Manager policy server"
    if [ -f $PDSTATUS -o -f $PDSTATUSLinux ] && [ -f $PDCONF -a -f $PDBAS ]; then
        AMHOST=`grep -v "#" $PDCONF | grep $PDMH | awk '{print $3}'`
        AMPORT=`grep -v "#" $PDCONF | grep $PDMP | awk '{print $3}'`

        $PDBAS -ping -h $AMHOST -p $AMPORT 1>/dev/null 2>/dev/null
     
  	     case $? in
            0) PrintMessage "    OK" ${ok} 
               ;;
            *) PrintMessage "    FAILED" ${failed}
               ;;
        esac
    else 
        PrintMessage "  AOSSR0160E   Could not find the Tivoli Access Manager Runtime configuration files." ${am_not_found}
    fi
}

set_ldap() {
    if [ -x $LDAP1 ]; then
        LDAP=$LDAP1
    elif [ -x $LDAP2 ]; then
        LDAP=$LDAP2
    else
        LDAP="NOT_FOUND"
    fi

    if [ -f $AMOSC ]; then
       LDAPHOST=`grep -v "#" $AMOSC | grep host | awk '{print $3}'`
    else
       LDAPHOST="NOT_FOUND"
    fi

    if [ -f $AMOSKDB ]; then
       AMOSKDB=$AMOSKDB
    else
       AMOSKDB="NOT_FOUND"
    fi
}

ping_ldap() {
    PrintMessage "Testing connectivity to LDAP Server (Non SSL)" ${ping_server} "LDAP Server (Non SSL)"
    if [ $LDAP = "NOT_FOUND" ]; then
	PrintMessage "AOSSR0162E   Could not find the ldapsearch utility." ${ldap_search_not_found}
        return
    fi
    if [ $LDAPHOST = "NOT_FOUND" ]; then
	PrintMessage "AOSSR0161E   Could not find the LDAP server hostname in the configuration file, /opt/PolicyDirector/etc/ldap.conf." ${ldap_host_not_found}
        return
    fi
    
    $LDAP -h $LDAPHOST -b "" -s base -v objectclass=* 1>/dev/null 2>/dev/null
    case $? in
        0) PrintMessage "    OK" ${ok}
           ;;
        *) PrintMessage "    FAILED" ${failed}
           ;;
    esac
}

ping_ldap_ssl() {
    PrintMessage "Testing connectivity to LDAP Server (SSL)" ${ping_server} "LDAP Server (SSL)"
    if [ $LDAP = "NOT_FOUND" ]; then
	PrintMessage "AOSSR0162E   Could not find the ldapsearch utility." ${ldap_search_not_found}
        return
    fi
    if [ $LDAPHOST = "NOT_FOUND" ]; then
	PrintMessage "AOSSR0161E   Could not find the LDAP server hostname in the configuration file, /opt/PolicyDirector/etc/ldap.conf." ${ldap_host_not_found}
        return
    fi
    if [ $AMOSKDB = "NOT_FOUND" ]; then
	PrintMessage "AOSSR0163E   Could not find the Tivoli Access Manager for Operating Systems key database file, /var/pdos/certs/pdosd.kdb." ${amos_kdb_not_found} 
        return
    fi
    
    $LDAP -h $LDAPHOST -Z -K $AMOSKDB -b "" -s base -v objectclass=* 1>/dev/null 2>/dev/null
    case $? in
        0) PrintMessage "    OK" ${ok}
           ;;
        *) PrintMessage "    FAILED" ${failed}
           ;;
    esac
}


### M A I N ###
ping_am
set_ldap
ping_ldap
ping_ldap_ssl
